pub const unsafe fn encode_rm64(rm64: GPROrMemory) -> EncodedX86_64InstructionExpand description
Pop 64-bit value from the stack into register or memory.
Safety
It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.